==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinOscillatorIndicatorDescription } from "./ChaikinOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ChaikinOscillatorIndicatorDescriptionMetadata.a == null) {
                ChaikinOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChaikinOscillatorIndicatorDescriptionMetadata.c(ChaikinOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(ChaikinOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ab(ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            ChaikinOscillatorIndicatorDescriptionMetadata.b(a);
            a.ad("ChaikinOscillatorIndicator", () => new ChaikinOscillatorIndicatorDescription());
            a.ac("ChaikinOscillatorIndicator", ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    ChaikinOscillatorIndicatorDescriptionMetadata.$t = markType(ChaikinOscillatorIndicatorDescriptionMetadata, 'ChaikinOscillatorIndicatorDescriptionMetadata');
    ChaikinOscillatorIndicatorDescriptionMetadata.a = null;
    return ChaikinOscillatorIndicatorDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ChaikinOscillatorIndicatorDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StrategyBasedIndicatorDescriptionMetadata } from "./StrategyBasedIndicatorDescriptionMetadata";
import { ChaikinOscillatorIndicatorDescription } from "./ChaikinOscillatorIndicatorDescription";
/**
 * @hidden
 */
export let ChaikinOscillatorIndicatorDescriptionMetadata = /*@__PURE__*/ (() => {
    class ChaikinOscillatorIndicatorDescriptionMetadata extends Base {
        static b(a) {
            if (ChaikinOscillatorIndicatorDescriptionMetadata.a == null) {
                ChaikinOscillatorIndicatorDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ChaikinOscillatorIndicatorDescriptionMetadata.c(ChaikinOscillatorIndicatorDescriptionMetadata.a);
            }
            if (a.k(ChaikinOscillatorIndicatorDescriptionMetadata.a)) {
                return;
            }
            a.ac(ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
        static c(a) {
            StrategyBasedIndicatorDescriptionMetadata.c(a);
            a.item("ShortPeriod", "Number:int");
            a.item("LongPeriod", "Number:int");
        }
        static d(a) {
            ChaikinOscillatorIndicatorDescriptionMetadata.b(a);
            a.ae("ChaikinOscillatorIndicator", () => new ChaikinOscillatorIndicatorDescription());
            a.ad("ChaikinOscillatorIndicator", ChaikinOscillatorIndicatorDescriptionMetadata.a);
        }
    }
    ChaikinOscillatorIndicatorDescriptionMetadata.$t = markType(ChaikinOscillatorIndicatorDescriptionMetadata, 'ChaikinOscillatorIndicatorDescriptionMetadata');
    ChaikinOscillatorIndicatorDescriptionMetadata.a = null;
    return ChaikinOscillatorIndicatorDescriptionMetadata;
})();
